#!/bin/bash

# Packager : guth <guth@ploposor.com> / JP <jp.guillemin@free.fr>
# Source : http://download.zenwalk.org/people/jp/netpkg/perl-pvfilter-0.2.tar.gz


softname="perl-pvfilter"
sourcefile="perl-pvfilter-0.3.tar.gz"
softversion="0.3"
perlversion="$(perl --version |grep '^This is perl' | cut -d ' ' -f 4 |cut -c 2-)"
packageversion='62.1'
arch='i486'
cpu='i686'

buildir=$(pwd)

if [ ! -e $sourcefile ]; then
    wget "$(grep -i '# *source *:' $0 | cut -d ':' -f 2-)"
fi

srcpkg="$buildir/$sourcefile"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"


cd $buildir
rm -rf $src
tar -xvf $srcpkg || exit -1
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest || exit -1
export CFLAGS="-O2 -march=$arch -mtune=$cpu"


# Build module
cd $src
# Adjust owner/perms to standard values:
chown -R root:root .
find . -perm 555 -exec chmod 755 {} \;
find . -perm 444 -exec chmod 644 {} \;

perl Makefile.PL
make
make install DESTDIR=$dest

# Strip everything:
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# docs
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a AUTHORS Artistic Copying INSTALL MANIFEST README README.Y2K \
README.cn README.jp README.ko README.micro README.tw Todo.micro \
$dest/usr/doc/$softname-$softversion/
chmod -R 644 $dest/usr/doc/$softname-$softversion/*


# Cleanup
( cd $dest/usr/share
  mv man .. )
chmod 644 $dest/usr/man/man?/*
rm -rf $dest/usr/share
cp -rf $dest/usr/lib/perl5/site_perl/$perlversion/* $dest/usr/lib/perl5/$perlversion/
rm -rf $dest/usr/lib/perl5/site_perl/$perlversion/*

# Gzip man !
gzip -9 $dest/usr/man/man?/*

cd $buildir

# Slack desc

mkdir -p $dest/install

cat << EODESC > "$dest/install/slack-desc"
#       |-----handy-ruler------------------------------------------------------|
$softname: $softname Perl module
$softname:
$softname: This is a Perl module for zenwalk package version parser
$softname: C binding
$softname: 
$softname: 
$softname: 
$softname: 
$softname: 
$softname: 
$softname: 
EODESC

# Welcome home

mkdir -p $dest/usr/src/$softname-$softversion
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion/

# adding the perllocal.pod mechanism

PERLVERSION=$(perl --version | grep v[0-9] | cut -d " " -f 4 | sed 's|v||g')
PERLBUILD=$(perl --version | grep v[0-9] | cut -d " " -f 7)
POD="usr/lib/perl5/${PERLVERSION}/${PERLBUILD}/perllocal.pod"
mv $dest/$POD $dest/$POD.$softname

cat >> $dest/install/doinst.sh <<EOF
perlpod() {
	# Get module name
        MODNAME=\$(head -1 ${POD}.\${1} |awk -F \| '{ print \$2 }' |sed 's/>//g')
        # get versions first just to make it easier
        MODVERNEW=\$(grep -m 1 -A 21 \${MODNAME} ${POD}.\${1} | sed 's/>//g' | awk '/VERSION/ {print \$2}')
        MODVEROLD=\$(grep -m 1 -A 21 \${MODNAME} ${POD} | sed 's/>//g' | awk '/VERSION/ {print \$2}')
        # check for pod file first off and simply use the new one if it doesn't exist
        if [ ! -f "${POD}" ]; then
                 mv ${POD}.\${1} ${POD}
        # if it does exist we need to look for the given module name in it
        elif [ ! "\$(grep -m 1 \${MODNAME} ${POD})" ]; then
                # if we don't find the name we can append our pod to the end of the original pod
                cat ${POD}.\${1} >> ${POD} && rm ${POD}.\${1}
        else
                # if we do find the module is already installed we need to check its version
                if [ "\${MODVERNEW}" != "\${MODVEROLD}" ]; then
                        # change version
                        firstline=\$(grep -m 1 -n \${MODNAME} ${POD} | awk -F: '{print \$1}')
                        lastline=\$((firstline+21))
                        sed -i "\${firstline},\${lastline}d" ${POD}
                        cat ${POD}.\${1} >> ${POD}
                        rm ${POD}.\${1}
                else
                        rm ${POD}.\${1}
                fi
        fi
}

perlpod $softname

EOF


# And finally, a package

cd $dest
/sbin/makepkg  -l y -c n $dest.tgz || exit -1
md5sum $dest.tgz > $dest.md5
